@@ -1,9 +1,6 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
 #![cfg_attr(feature = "dox", feature(doc_cfg))]
-#![allow(clippy::derive_hash_xor_eq)]
-#![allow(clippy::too_many_arguments)]
-#![allow(clippy::wrong_self_convention)]
 #![doc = include_str!("../README.md")]
 
 pub use cairo;
@@ -23,17 +20,11 @@ macro_rules! skip_assert_initialized {
     () => {};
 }
 
-#[allow(clippy::upper_case_acronyms)]
-#[allow(unused_imports)]
+#[allow(clippy::derive_hash_xor_eq)]
 mod auto;
 
+pub mod builders;
 pub mod prelude;
-// rustdoc-stripper-ignore-next
-/// Builder pattern types.
-pub mod builders {
-    pub use crate::ShaderArgsBuilder;
-}
-
 pub use auto::*;
 
 #[macro_use]
@@ -72,6 +63,7 @@ mod rounded_clip_node;
 mod shadow_node;
 mod text_node;
 mod texture_node;
+mod transform;
 mod transform_node;
 
 pub use color_stop::ColorStop;
